@@ -21,7 +21,7 @@ desc_stats_by_group <- function(
   grouping_vars = NULL,
   sigfigs = NULL,
   cols_to_round = NULL) {
-  dt1 <- setDT(copy(data))
+  dt1 <- data.table::setDT(data.table::copy(data))
   dt2 <- dt1[!is.na(get(var_for_stats)), list(
     n = length(get(var_for_stats)),
     mean = as.numeric(mean(get(var_for_stats), na.rm = TRUE)),
@@ -58,7 +58,7 @@ desc_stats_by_group <- function(
         "mean", "sd", "median", "se", "ci_95_ll", "ci_95_ul", "pi_95_ll",
         "pi_95_ul", "skewness", "kurtosis")
     }
-    dt2 <- dt2[, (cols_to_round) := signif(.SD, sigfigs),
+    dt2 <- dt2[, (cols_to_round) := kim::round_flexibly(.SD, sigfigs),
                .SDcols = cols_to_round][]
   }
   return(dt2)
