@@ -14,13 +14,13 @@
 #' this value will be set as 30 * number of variables.
 #' @param percentile_for_eigenvalue percentile used in estimating bias
 #' (default = 95).
-#'
 #' @examples
+#' \donttest{
 #' parallel_analysis(
-#'   data = mtcars, names_of_vars = c("disp", "hp", "drat")
-#' )
+#'   data = mtcars, names_of_vars = c("disp", "hp", "drat"))
 #' # parallel_analysis(
 #' # data = mtcars, names_of_vars = c("carb", "vs", "gear", "am"))
+#' }
 #' @export
 # parallel analysis factor analysis
 parallel_analysis <- function(
@@ -28,8 +28,10 @@ parallel_analysis <- function(
   names_of_vars = NULL,
   iterations = NULL,
   percentile_for_eigenvalue = 95) {
+  # installed packages
+  installed_pkgs <- rownames(utils::installed.packages())
   # check if Package 'ggplot2' is installed
-  if (!"ggplot2" %in% rownames(utils::installed.packages())) {
+  if (!"ggplot2" %in% installed_pkgs) {
     message(paste0(
       "This function requires the installation of Package 'ggplot2'.",
       "\nTo install Package 'ggplot2', type ",
@@ -38,12 +40,9 @@ parallel_analysis <- function(
       "for all\nfunctions in Package 'kim', type ",
       "'kim::install_all_dependencies()'"))
     return()
-  } else {
-    # proceed if Package 'ggplot2' is already installed
-    kim::prep("ggplot2")
   }
   # check if Package 'paran' is installed
-  if (!"paran" %in% rownames(utils::installed.packages())) {
+  if (!"paran" %in% installed_pkgs) {
     message(paste0(
       "To conduct a parallel analysis, Package 'paran' must ",
       "be installed.\nTo install Package 'paran', type ",
@@ -59,7 +58,8 @@ parallel_analysis <- function(
   # bind the vars locally to the function
   eigenvalue <- eigenvalue_type <- NULL
   # convert to data table and omit na
-  dt <- data.table::setDT(copy(data))[, names_of_vars, with = FALSE]
+  dt <- data.table::setDT(data.table::copy(
+    data))[, names_of_vars, with = FALSE]
   # stats::na.omit(
   sample_size <- nrow(dt)
   # set default number of iterations
@@ -106,46 +106,34 @@ parallel_analysis <- function(
   dt4 <- rbind(dt2, dt3)
   dt5 <- subset(dt4, component_number == 1)
   # plot
-  g1 <- ggplot(dt4, aes(
+  g1 <- ggplot2::ggplot(dt4, ggplot2::aes(
     x = component_number,
     y = eigenvalue,
     group = eigenvalue_type,
-    color = eigenvalue_type
-  )) +
-    geom_point(aes(color = eigenvalue_type),
-               size = 4
-    ) +
-    geom_line(aes(color = eigenvalue_type),
-              size = 2
-    ) +
-    geom_text(
-      data = dt5,
-      aes(
-        x = component_number,
-        y = eigenvalue,
-        label = eigenvalue_type,
-        color = eigenvalue_type,
-        hjust = -0.1, vjust = -0.1
-      ),
-      fontface = "bold",
-      size = 4,
-      inherit.aes = F
-    ) +
-    theme_classic(base_size = 16) %+replace%
-    theme(
-      plot.title = element_text(hjust = 0.5),
+    color = eigenvalue_type))
+  g1 <- g1 + ggplot2::geom_point(
+    ggplot2::aes(color = eigenvalue_type), size = 4)
+  g1 <- g1 + ggplot2::geom_line(
+    ggplot2::aes(color = eigenvalue_type), size = 2)
+  g1 <- g1 + ggplot2::geom_text(data = dt5, ggplot2::aes(
+    x = component_number, y = eigenvalue, label = eigenvalue_type,
+    color = eigenvalue_type, hjust = -0.1, vjust = -0.1),
+    fontface = "bold", size = 4, inherit.aes = F)
+  g1 <- g1 + ggplot2::theme_classic(base_size = 16) +
+    ggplot2::theme(
+      plot.title = ggplot2::element_text(hjust = 0.5),
       legend.position = "none",
-      axis.text = element_text(color = "black", size = 12),
-      axis.title.x = element_text(margin = margin(t = 12)),
-      axis.title.y = element_text(
-        angle = 90, margin = margin(r = 12)
-      )
-    ) +
-    theme(plot.subtitle = element_text(hjust = 0.5)) +
-    scale_x_continuous(breaks = component_number) +
-    xlab("\nComponent Number") +
-    ylab("Eigenvalue\n")
-  g1 <- g1 + labs(
+      axis.text = ggplot2::element_text(color = "black", size = 12),
+      axis.title.x = ggplot2::element_text(
+        margin = ggplot2::margin(t = 12)),
+      axis.title.y = ggplot2::element_text(
+        angle = 90, margin = ggplot2::margin(r = 12)))
+  g1 <- g1 + ggplot2::theme(
+    plot.subtitle = ggplot2::element_text(hjust = 0.5)) +
+    ggplot2::scale_x_continuous(breaks = component_number) +
+    ggplot2::xlab("\nComponent Number") +
+    ggplot2::ylab("Eigenvalue\n")
+  g1 <- g1 + ggplot2::labs(
     title = paste0(
       "Parallel Analysis Result: ", number_of_retained_factors,
       " Factor",
@@ -153,7 +141,7 @@ parallel_analysis <- function(
       " to Retain\n"
     )
   )
-  g1 <- g1 + labs(subtitle = bquote(
+  g1 <- g1 + ggplot2::labs(subtitle = bquote(
     italic(N) ~ " = " ~ .(sample_size)
   ))
   return(g1)
