@@ -19,7 +19,7 @@
 #' @param alpha opacity of the dots (0 = completely transparent,
 #' 1 = completely opaque)
 #' @param annotate_stats if \code{TRUE}, the correlation and p-value will
-#' be annotated at the top of the plot
+#' be annotated at the top of the plot (default = TRUE)
 #' @param annotate_y_pos position of the annotated stats, expressed
 #' as a percentage of the range of y values by which the annotated
 #' stats will be placed above the maximum value of y in the data set
@@ -27,14 +27,22 @@
 #' maximum y values in the data set are 0 and 100, respectively,
 #' the annotated stats will be placed at 5% of the y range (100 - 0)
 #' above the maximum y value, y = 0.05 * (100 - 0) + 100 = 105.
+#' @param annotated_stats_color color of the annotated stats
+#' (default = "green4").
+#' @param annotated_stats_font_size font size of the annotated stats
+#' (default = 6).
+#' @param annotated_stats_font_face font face of the annotated stats
+#' (default = "bold").
 #' @param line_of_fit_type if \code{line_of_fit_type = "lm"}, a regression
 #' line will be fit; if \code{line_of_fit_type = "loess"}, a local
 #' regression line will be fit; if \code{line_of_fit_type = "none"},
 #' no line will be fit
 #' @param ci_for_line_of_fit if \code{ci_for_line_of_fit = TRUE},
 #' confidence interval for the line of fit will be shaded
+#' @param line_of_fit_color color of the line of fit (default = "blue")
 #' @param x_axis_label alternative label for the x axis
 #' @param y_axis_label alternative label for the y axis
+#' @param point_size size of the dots on the plot (default = 2)
 #' @param point_label_size size for dots' labels on the plot. If no
 #' input is entered for this argument, it will be set as
 #' \code{point_label_size = 5} by default. If the plot is to be
@@ -72,19 +80,26 @@ scatterplot <- function(
   point_label_var_name = NULL,
   weight_var_name = NULL,
   alpha = 1,
-  annotate_stats = FALSE,
+  annotate_stats = TRUE,
   annotate_y_pos = 5,
+  annotated_stats_color = "green4",
+  annotated_stats_font_size = 6,
+  annotated_stats_font_face = "bold",
   line_of_fit_type = "lm",
   ci_for_line_of_fit = FALSE,
+  line_of_fit_color = "blue",
   x_axis_label = NULL,
   y_axis_label = NULL,
+  point_size = 2,
   point_label_size = NULL,
   point_size_range = c(3, 12),
   jitter_x_percent = 0,
   jitter_y_percent = 0,
   cap_axis_lines = FALSE) {
+  # installed packages
+  installed_pkgs <- rownames(utils::installed.packages())
   # check if Package 'ggplot2' is installed
-  if (!"ggplot2" %in% rownames(utils::installed.packages())) {
+  if (!"ggplot2" %in% installed_pkgs) {
     message(paste0(
       "This function requires the installation of Package 'ggplot2'.",
       "\nTo install Package 'ggplot2', type ",
@@ -93,14 +108,11 @@ scatterplot <- function(
       "for all\nfunctions in Package 'kim', type ",
       "'kim::install_all_dependencies()'"))
     return()
-  } else {
-    # proceed if Package 'ggplot2' is already installed
-    kim::prep("ggplot2")
   }
   # weighted correlation
   if (!is.null(weight_var_name)) {
     # check if weights package is installed
-    if (!"weights" %in% rownames(utils::installed.packages())) {
+    if (!"weights" %in% installed_pkgs) {
       message(paste0(
         "To calculate weighted correlation(s), Package 'weights' must ",
         "be installed.\nTo install Package 'weights', type ",
@@ -115,65 +127,68 @@ scatterplot <- function(
     }
   }
   # create a temporary dataset
-  dt01 <- data.table(x = data[[x_var_name]], y = data[[y_var_name]])
+  dt01 <- data.table::data.table(
+    x = data[[x_var_name]], y = data[[y_var_name]])
   # add the point label or weight column
   if (!is.null(point_label_var_name)) {
-    dt01 <- data.table(
-      dt01,
-      point_labels = data[[point_label_var_name]]
-    )
+    data.table::set(
+      dt01, j = "point_labels", value = data[[point_label_var_name]])
   }
   if (!is.null(weight_var_name)) {
-    dt01 <- data.table(dt01, weight = data[[weight_var_name]])
+    data.table::set(
+      dt01, j = "weight", value = data[[weight_var_name]])
   } else {
     # set weight as 1 if no weight_var_name is given
-    dt01 <- data.table(dt01, weight = 1)
+    data.table::set(dt01, j = "weight", value = 1)
   }
   # remove na values
+  num_of_na_rows <- sum(!stats::complete.cases(dt01))
   dt02 <- stats::na.omit(dt01)
-  if (nrow(dt02) < nrow(dt01)) {
+  if (num_of_na_rows > 0) {
     message(paste0(
-      nrow(dt01) - nrow(dt02),
-      " rows were removed because of missing values."
-    ))
+      num_of_na_rows,
+      " rows were removed because of missing values."))
   }
   # ranges for x and y
   x_range <- max(dt02$x) - min(dt02$x)
   y_range <- max(dt02$y) - min(dt02$y)
   # start ggplot
-  g1 <- ggplot(data = dt02, aes(x = dt02$x, y = dt02$y))
+  g1 <- ggplot2::ggplot(data = dt02, ggplot2::aes(x = dt02$x, y = dt02$y))
   # add jitter
-  pj <- position_jitter(
+  pj <- ggplot2::position_jitter(
     width = jitter_x_percent / 100 * x_range,
     height = jitter_y_percent / 100 * y_range
   )
   # add point labels or dots
   if (!is.null(point_label_var_name)) {
-    g1 <- g1 + aes(label = dt02$point_labels)
+    g1 <- g1 + ggplot2::aes(label = dt02$point_labels)
     if (is.null(point_label_size)) {
-      g1 <- g1 + geom_text(
-        aes(label = dt02$point_labels, fontface = "bold"),
+      g1 <- g1 + ggplot2::geom_text(
+        ggplot2::aes(label = dt02$point_labels, fontface = "bold"),
         position = pj)
     } else {
-      g1 <- g1 + geom_text(
-        aes(label = dt02$point_labels, fontface = "bold"),
+      g1 <- g1 + ggplot2::geom_text(
+        ggplot2::aes(label = dt02$point_labels, fontface = "bold"),
         position = pj,
         size = point_label_size)
     }
   } else {
-    g1 <- g1 + geom_point(position = pj, alpha = alpha)
+    g1 <- g1 + ggplot2::geom_point(
+      position = pj, alpha = alpha, size = point_size)
   }
   # scale points
   if (!is.null(weight_var_name)) {
-    g1 <- g1 + aes(size = dt02$weight)
-    g1 <- g1 + scale_size(
+    g1 <- g1 + ggplot2::aes(size = dt02$weight)
+    g1 <- g1 + ggplot2::scale_size(
       range = point_size_range, guide = FALSE)
   }
   # weighted least squares line
   if (line_of_fit_type %in% c("lm", "loess")) {
-    g1 <- g1 + geom_smooth(
+    g1 <- g1 + ggplot2::geom_smooth(
       formula = y ~ x,
-      method = line_of_fit_type, mapping = aes(weight = dt02$weight),
+      method = line_of_fit_type,
+      mapping = ggplot2::aes(weight = dt02$weight),
+      color = line_of_fit_color,
       se = ci_for_line_of_fit
     )
   }
@@ -193,8 +208,8 @@ scatterplot <- function(
     weighted_r_text <- "weighted"
   }
   # nice p value
-  cor_test_p_value_text <-
-    pretty_round_p_value(cor_test_p_value, include_p_equals = TRUE)
+  cor_test_p_value_text <- kim::pretty_round_p_value(
+    cor_test_p_value, include_p_equals = TRUE)
   # annotate stats
   if (annotate_stats == TRUE) {
     annotation_01 <-
@@ -212,15 +227,14 @@ scatterplot <- function(
           t06 = weighted_r_text
         )
       )))
-    g1 <- g1 + geom_text(
-      aes(
-        x = min(dt02$x) + x_range / 2,
-        y = max(dt02$y) + y_range * annotate_y_pos / 100),
-      color = "green4",
+    g1 <- g1 + ggplot2::geom_text(ggplot2::aes(
+      x = min(dt02$x) + x_range / 2,
+      y = max(dt02$y) + y_range * annotate_y_pos / 100),
+      color = annotated_stats_color,
       label = annotation_01, parse = TRUE,
       hjust = 0.5, vjust = 0.5,
-      size = 6,
-      fontface = "bold"
+      size = annotated_stats_font_size,
+      fontface = annotated_stats_font_face
     )
   }
   # axis labels
@@ -230,10 +244,10 @@ scatterplot <- function(
   if (is.null(y_axis_label)) {
     y_axis_label <- y_var_name
   }
-  g1 <- g1 + xlab(x_axis_label)
-  g1 <- g1 + ylab(y_axis_label)
+  g1 <- g1 + ggplot2::xlab(x_axis_label)
+  g1 <- g1 + ggplot2::ylab(y_axis_label)
   # plot theme
-  g1 <- g1 + theme_kim(cap_axis_lines = cap_axis_lines)
+  g1 <- g1 + kim::theme_kim(cap_axis_lines = cap_axis_lines)
   # return the ggplot
   return(g1)
 }
