@@ -3,9 +3,9 @@
 #' Score items in a scale (e.g., Likert scale items) by computing the
 #' sum or mean of the items.
 #'
-#' @param items list of scale items (i.e., list of vectors of ratings)
+#' @param item_list a list of scale items (i.e., list of vectors of ratings)
 #' to code normally (as opposed to reverse coding).
-#' @param reverse list of scale items to reverse code.
+#' @param reverse_item_list a list of scale items to reverse code.
 #' @param operation if \code{operation = "mean"}, mean of the scale items
 #' will be calculated; if \code{operation = "sum"}, sum of the scale items
 #' will be calculated (default = "mean").
@@ -17,22 +17,25 @@
 #' if the items to reverse code are measured on a 7-point scale, enter
 #' \code{reverse_code_minuend = 8}.
 #' @examples
-#' score_scale_items(items = list(1:5, rep(3, 5)),
-#' reverse = list(rep(5, 5)), reverse_code_minuend = 6)
-#' score_scale_items(items = list(c(1, 1), c(1, 5)),
-#' reverse = list(c(5, 3)), reverse_code_minuend = 6, na_summary = FALSE)
-#' score_scale_items(items = list(c(1, 1), c(1, 5)),
-#' reverse = list(c(5, 1)), reverse_code_minuend = 6, operation = "sum")
+#' score_scale_items(item_list = list(1:5, rep(3, 5)),
+#' reverse_item_list = list(rep(5, 5)), reverse_code_minuend = 6)
+#' score_scale_items(item_list = list(c(1, 1), c(1, 5)),
+#' reverse_item_list = list(c(5, 3)),
+#' reverse_code_minuend = 6, na_summary = FALSE)
+#' score_scale_items(item_list = list(c(1, 1), c(1, 5)),
+#' reverse_item_list = list(c(5, 1)),
+#' reverse_code_minuend = 6, operation = "sum")
+#' score_scale_items(item_list = list(1:5, rep(3, 5)))
 #' @export
 #' @import data.table
 score_scale_items <- function(
-  items = NULL,
-  reverse = NULL,
+  item_list = NULL,
+  reverse_item_list = NULL,
   operation = "mean",
   na_summary = TRUE,
   reverse_code_minuend = NULL) {
   # deal with argument inputs
-  if (!is.null(reverse)) {
+  if (!is.null(reverse_item_list)) {
     if (is.null(reverse_code_minuend)) {
       stop(paste0(
         "Please enter the minuend for reverse coding.\n",
@@ -43,9 +46,9 @@ score_scale_items <- function(
   # print a summary of na values
   if (na_summary == TRUE) {
     # report na values in normally coded items
-    if (!is.null(items)) {
-      na_summary_1 <- vapply(seq_along(items), function(i) {
-        sum(is.na(items[[i]]))
+    if (!is.null(item_list)) {
+      na_summary_1 <- vapply(seq_along(item_list), function(i) {
+        sum(is.na(item_list[[i]]))
       }, FUN.VALUE = numeric(1L))
       if (length(na_summary_1) > 0) {
         na_summary_1_name <- paste0("item_", seq_along(na_summary_1))
@@ -56,9 +59,9 @@ score_scale_items <- function(
       na_summary_1_name <- NULL
     }
     # report na values in reverse coded items
-    if (!is.null(reverse)) {
-      na_summary_2 <- vapply(seq_along(reverse), function(i) {
-        sum(is.na(reverse[[i]]))
+    if (!is.null(reverse_item_list)) {
+      na_summary_2 <- vapply(seq_along(reverse_item_list), function(i) {
+        sum(is.na(reverse_item_list[[i]]))
       }, FUN.VALUE = numeric(1L))
       if (length(na_summary_2) > 0) {
         na_summary_2_name <- paste0(
@@ -68,9 +71,10 @@ score_scale_items <- function(
       }
     } else {
       na_summary_2_name <- NULL
+      na_summary_2 <- NULL
     }
     # na summary table
-    na_summary_final <- data.table(
+    na_summary_final <- data.table::data.table(
       item = c(na_summary_1_name, na_summary_2_name),
       number_of_na_values = c(na_summary_1, na_summary_2))
     # report
@@ -82,18 +86,18 @@ score_scale_items <- function(
     print(na_summary_final)
   }
   # reverse code items
-  if (!is.null(reverse)) {
-    reverse_coded <- lapply(seq_along(reverse), function(i) {
-      ratings <- reverse[[i]]
+  if (!is.null(reverse_item_list)) {
+    reverse_coded <- lapply(seq_along(reverse_item_list), function(i) {
+      ratings <- reverse_item_list[[i]]
       output <- reverse_code_minuend - ratings
       return(output)
     })
-    items_after_rev_coding <- c(items, reverse_coded)
+    items_after_rev_coding <- c(item_list, reverse_coded)
   } else {
-    items_after_rev_coding <- items
+    items_after_rev_coding <- item_list
   }
   # data table of item ratings
-  ratings_dt <- setDT(items_after_rev_coding)[]
+  ratings_dt <- data.table::setDT(items_after_rev_coding)[]
   # calculate mean
   if (operation == "mean") {
     output <- rowMeans(ratings_dt, na.rm = TRUE)
